@@ -20,7 +20,6 @@
 
 #include <math.h>
 #include <sys/time.h>
-#include <stdlib.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
@@ -42,7 +41,7 @@
 \*                                             */
 
 #include <kscreensaver.h>
-#include <kdialogbase.h>
+#include <kdialog.h>
 
 class KFireSaverKSS : public KScreenSaver
 {
@@ -66,16 +65,16 @@ class KFireSaverKSS : public KScreenSaver
 	KFireSaver* saver;
 };
 
-class KFireSaverSetupKDB : public KDialogBase
+class KFireSaverSetupKDB : public KDialog
 {
     public:
-	KFireSaverSetupKDB( QWidget* parent = 0, const char* name = 0 )
-	    : KDialogBase( parent, name, true, i18n("Setup Screen Saver"),
+	KFireSaverSetupKDB( QWidget* parent = 0 )
+	    : KDialog( parent, name, true, i18n("Setup Screen Saver"),
 	    Ok | Cancel | Help, Ok, true )
 	{
 		setup = new KFireSaverSetup( this );
 		setMainWidget( setup );
-		setButtonText( KDialogBase::Help, i18n( "A&bout" ) );
+		setButtonText( KDialog::Help, i18n( "A&bout" ) );
 	}
 
     private slots:
@@ -93,29 +92,39 @@ class KFireSaverSetupKDB : public KDialogBase
 	KFireSaverSetup * setup;
 };
 
-extern "C"
+class KFireSaverInterface : public KScreenSaverInterface
 {
-    KDE_EXPORT const char *kss_applicationName = "kfiresaver.kss";
-    KDE_EXPORT const char *kss_description = I18N_NOOP( "Fireworks 3D (GL)" );
-    KDE_EXPORT const char *kss_version = "0.7";
 
-    KDE_EXPORT KScreenSaver *kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "kfiresaver.kss", 0, ki18n( "Fireworks 3D (GL)" ), "0.7", ki18n( "Fireworks 3D (GL)" ) );
+    }
+
+
+    virtual KScreenSaver* create( WId id )
     {
 	return new KFireSaverKSS( id );
     }
 
-    KDE_EXPORT QDialog *kss_setup()
+    virtual QDialog* setup()
     {
 	return new KFireSaverSetupKDB;
     }
+};
+
+int main( int argc, char *argv[] )
+{
+    KFireSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 /*                                             *\
 \* Factory code for KScreensaver ends *here*   */
 
 
-KFireSaver :: KFireSaver( QWidget *parent, const char *name )
-	: QGLWidget( parent, name )
+KFireSaver :: KFireSaver( QWidget *parent )
+	: QGLWidget( parent )
 {
 	// set random seed to initialize drand48() calls
 	timeval tv;
@@ -124,16 +133,11 @@ KFireSaver :: KFireSaver( QWidget *parent, const char *name )
 
 	readConfig();
 
-	particleList.setAutoDelete(true);
-	starList.setAutoDelete(true);
-	imageList.setAutoDelete(true);
-	playObjectList.setAutoDelete(true);
-
 	//initialize openGL context before managing GL calls
 	makeCurrent();
-	loadTexture( locate("data","kfiresaver/kfs_particle.png"), particleTexture );
-	loadTexture( locate("data","kfiresaver/kfs_particle_flare.png"), flareTexture );
-	loadTexture( locate("data","kfiresaver/kfs_particle_diastar.png"), diastarTexture );
+	loadTexture( KStandardDirs::locate("data","kfiresaver/kfs_particle.png"), particleTexture );
+	loadTexture( KStandardDirs::locate("data","kfiresaver/kfs_particle_flare.png"), flareTexture );
+	loadTexture( KStandardDirs::locate("data","kfiresaver/kfs_particle_diastar.png"), diastarTexture );
 	starTexture = particleTexture;
 
 	//generate stars
@@ -211,6 +215,11 @@ KFireSaver :: ~KFireSaver()
 	playObjectList.clear();
 	if ( parameters.enableWritings )
 		delete writer;
+
+	qDeleteAll(particleList);
+	qDeleteAll(starList);
+	qDeleteAll(imageList);
+	qDeleteAll(playObjectList);
 }
 
 
@@ -520,14 +529,11 @@ void KFireSaver :: paintGL ()
 		if ( !chance ) {
 			static const QString someStrings[] = {
 				i18n("www.kde.org"),
-				i18n("My KDE, please!"),
-				i18n("KoNqUeR the World"),
+				i18n("Conquer your desktop!"),
 				i18n("KFIRESAVER 3D"),
-				i18n("Gimme your eyes..."),
 				i18n("Thank you for using KDE"),
-				i18n("Going insane tonight"),
 			};
-			int n = (int)(6.0 * DRAND);
+			int n = (int)(4.0 * DRAND);
 			writer->spawnWords( someStrings[n], Writer::Fun1 );
 		}
 		writer->render( timeDiff );
@@ -819,14 +825,14 @@ void KFireSaver :: timerEvent(QTimerEvent*)
 	{
 	    case Monotype:
 		/* first time choose the type, color and attributes will
-		   be choosed randomly for every firework which explodes*/
+		   be chosen randomly for every firework which explodes*/
 		showp.forceType = true;
 		chooseType = true;
 		break;
 
 	    case Monochrome:
 		/* first time choose the color, type and attributes will
-		   be choosed randomly for every firework which explodes*/
+		   be chosen randomly for every firework which explodes*/
 		showp.forceColour = true;
 		chooseColor =
 		chooseOthers = true;
@@ -958,7 +964,7 @@ void KFireSaver :: playSound(QString file)
 		//return;
 
 	KPlayObjectFactory factory(artsServer.server());
-	playObject = factory.createPlayObject(KURL(file), true);
+	playObject = factory.createPlayObject(KUrl(file), true);
 
 	if (playObject && !playObject->isNull())
 	{
@@ -1005,141 +1011,141 @@ void KFireSaver :: readConfig ()
 
 	// show
 	config.setGroup( "Show" );
-	showp.ShowType = (enum enumShowType)config.readNumEntry( "ShowType", 1 );
-	parameters.fireworksFrequency = 11 - config.readNumEntry( "FireworksFrequency", 7 );
+	showp.ShowType = (enum enumShowType)config.readEntry( "ShowType", 1 );
+	parameters.fireworksFrequency = 11 - config.readEntry( "FireworksFrequency", 7 );
 	if ( parameters.fireworksFrequency < 1 )
 		parameters.fireworksFrequency = 1;
 	if ( parameters.fireworksFrequency > 11 )
 		parameters.fireworksFrequency = 11;
 	parameters.fireworksFrequency *= (parameters.fireworksFrequency + 1); //*karl gauss's sum*
-	parameters.particleSize = config.readNumEntry( "ParticlesSize", 0 );
+	parameters.particleSize = config.readEntry( "ParticlesSize", 0 );
 	if ( parameters.particleSize < -5 )
 		parameters.particleSize = -5;
 	if ( parameters.particleSize > 5 )
 		parameters.particleSize = 5;
-	if ( parameters.enableBottomFire = config.readBoolEntry( "enable-BottomFire", true ) )
+	if ( parameters.enableBottomFire = config.readEntry( "enable-BottomFire", true ) )
 	{
 		QColor blue = Qt::darkBlue;
-		parameters.bottomFireColor = config.readColorEntry( "BottomFireColor", &blue );
+		parameters.bottomFireColor = config.readEntry( "BottomFireColor", blue );
 	}
-	parameters.enableSound = config.readBoolEntry( "enable-Sounds", false );
-	parameters.enableNoOverhead = config.readBoolEntry( "enable-NoOverhead", true );
-	parameters.enableRealtime = config.readBoolEntry( "enable-FrameSkip", true );
+	parameters.enableSound = config.readEntry( "enable-Sounds", false );
+	parameters.enableNoOverhead = config.readEntry( "enable-NoOverhead", true );
+	parameters.enableRealtime = config.readEntry( "enable-FrameSkip", true );
 
 	// fireworks
 	config.setGroup( "Fireworks" );
 	parameters.typesCount = 0;
-	if ( config.readBoolEntry( "use-Classic", true ) )
+	if ( config.readEntry( "use-Classic", true ) )
 		parameters.typesT[parameters.typesCount++] = Sphere;
-	if ( config.readBoolEntry( "use-Explosion", false ) )
+	if ( config.readEntry( "use-Explosion", false ) )
 		parameters.typesT[parameters.typesCount++] = NoFW;
-	if ( config.readBoolEntry( "use-FlameRing", false ) )
+	if ( config.readEntry( "use-FlameRing", false ) )
 		parameters.typesT[parameters.typesCount++] = Circle;
-	if ( config.readBoolEntry( "use-FlameWorld", false ) )
+	if ( config.readEntry( "use-FlameWorld", false ) )
 		parameters.typesT[parameters.typesCount++] = BiCircle;
-	if ( config.readBoolEntry( "use-Fall", false ) )
+	if ( config.readEntry( "use-Fall", false ) )
 		parameters.typesT[parameters.typesCount++] = AngelHairs;
-	if ( config.readBoolEntry( "use-Splitter", false ) )
+	if ( config.readEntry( "use-Splitter", false ) )
 		parameters.typesT[parameters.typesCount++] = Splitter;
-	if ( config.readBoolEntry( "use-Spirals", false ) )
+	if ( config.readEntry( "use-Spirals", false ) )
 		parameters.typesT[parameters.typesCount++] = Spirals;
-	if ( config.readBoolEntry( "use-SuperNova", false ) )
+	if ( config.readEntry( "use-SuperNova", false ) )
 		parameters.typesT[parameters.typesCount++] = SuperNova;
 	if ( !parameters.typesCount ) {
-		kdWarning() << "KFireSaver3D: Warning, no fireworks enabled in config file" << endl;
-		kdWarning() << "    enabling 'Classic Spherical'" << endl;
+		kWarning() << "KFireSaver3D: Warning, no fireworks enabled in config file" ;
+		kWarning() << "    enabling 'Classic Spherical'" ;
 		parameters.typesCount = 1;
 		parameters.typesT[0] = Sphere;
 	}
 	parameters.typesT[ parameters.typesCount ] =
 		parameters.typesT[ parameters.typesCount-1 ];
 	parameters.colorsCount = 0;
-	if ( config.readBoolEntry( "use-Red", false ) )
+	if ( config.readEntry( "use-Red", false ) )
 		parameters.colorsT[parameters.colorsCount++] = 0;
-	if ( config.readBoolEntry( "use-Orange", true ) )
+	if ( config.readEntry( "use-Orange", true ) )
 		parameters.colorsT[parameters.colorsCount++] = 1;
-	if ( config.readBoolEntry( "use-Green", false ) )
+	if ( config.readEntry( "use-Green", false ) )
 		parameters.colorsT[parameters.colorsCount++] = 2;
-	if ( config.readBoolEntry( "use-Blue", false ) )
+	if ( config.readEntry( "use-Blue", false ) )
 		parameters.colorsT[parameters.colorsCount++] = 3;
-	if ( config.readBoolEntry( "use-White", true ) )
+	if ( config.readEntry( "use-White", true ) )
 		parameters.colorsT[parameters.colorsCount++] = 4;
-	if ( config.readBoolEntry( "use-Purple", false ) )
+	if ( config.readEntry( "use-Purple", false ) )
 		parameters.colorsT[parameters.colorsCount++] = 5;
-	if ( config.readBoolEntry( "use-DeepGreen", true ) )
+	if ( config.readEntry( "use-DeepGreen", true ) )
 		parameters.colorsT[parameters.colorsCount++] = 6;
 	if ( !parameters.colorsCount )
 	{
-		kdWarning() << "KFireSaver3D: Warning enable at least one color" << endl;
-		kdWarning() << "    enabling 'Blinding White'" << endl;
+		kWarning() << "KFireSaver3D: Warning enable at least one color" ;
+		kWarning() << "    enabling 'Blinding White'" ;
 		parameters.colorsCount = 1;
 		parameters.colorsT[0] = 4;
 	}
 	parameters.colorsT[ parameters.colorsCount ] =
 		parameters.colorsT[ parameters.colorsCount-1 ];
-	parameters.enableCombos = config.readBoolEntry( "use-Multicolor", true );
+	parameters.enableCombos = config.readEntry( "use-Multicolor", true );
 
 	// specials
 	config.setGroup( "Specials" );
-	if ( parameters.enableLogos = config.readBoolEntry( "enable-Logos", true ) )
+	if ( parameters.enableLogos = config.readEntry( "enable-Logos", true ) )
 	{
 		QImage tempImage;
 		tempImage.setAlphaBuffer( true );
-		if ( config.readBoolEntry( "LogosTux", true ) )
+		if ( config.readEntry( "LogosTux", true ) )
 			if ( tempImage.load(locate("data","kfiresaver/kfs_tux.png")) )
 				imageList.append( new QImage(tempImage) );
-		if ( config.readBoolEntry( "LogosKonqui", true ) )
+		if ( config.readEntry( "LogosKonqui", true ) )
 			if ( tempImage.load(locate("data","kfiresaver/kfs_kde.png")) )
 				imageList.append( new QImage(tempImage) );
-		if ( config.readBoolEntry( "LogosKDEIcons", true ) ) {
+		if ( config.readEntry( "LogosKDEIcons", true ) ) {
 			const QString icons[] = {
-				"3floppy_unmount", "cdrom_unmount", "hdd_mount", "kmix",
-				"network", "my-computer", "folder_home", "konqueror",
-				"kmail", "penguin", "personal" };
+				"media-floppy", "media-optical", "drive-harddisk", "kmix",
+				"network-wired", "computer", "user-home", "konqueror",
+				"internet-mail", "graphics-viewer-document", "user-identity" };
 			for ( int i = 0; i < 11; i++ )
 				imageList.append( new QImage(DesktopIcon(icons[i],64).convertToImage()) );
 		}
-		parameters.enableReduceLogo = config.readBoolEntry( "LogosReduceDetail", true );
-		parameters.logoFrequency = 11 - config.readNumEntry( "LogosFrequency", 4 );
+		parameters.enableReduceLogo = config.readEntry( "LogosReduceDetail", true );
+		parameters.logoFrequency = 11 - config.readEntry( "LogosFrequency", 4 );
 		if ( parameters.logoFrequency < 1 )
 			parameters.logoFrequency = 1;
 		if ( parameters.logoFrequency > 11 )
 			parameters.logoFrequency = 11;
 	}
-	if ( parameters.enableStars = config.readBoolEntry( "enable-Stars", true ) )
+	if ( parameters.enableStars = config.readEntry( "enable-Stars", true ) )
 	{
-		parameters.enableStarFlickering = config.readBoolEntry( "StarsFlicker", false );
-		parameters.enableStarGradient = config.readBoolEntry( "StarsGradient", true );
-		parameters.starsNumber = config.readNumEntry( "StarsNumber", 4 );
+		parameters.enableStarFlickering = config.readEntry( "StarsFlicker", false );
+		parameters.enableStarGradient = config.readEntry( "StarsGradient", true );
+		parameters.starsNumber = config.readEntry( "StarsNumber", 4 );
 		if ( parameters.starsNumber < 0 )
 			parameters.starsNumber = 0;
 		if ( parameters.starsNumber > 10 )
 			parameters.starsNumber = 10;
 	}
-	parameters.enableWritings = config.readBoolEntry( "enable-Writings", true );
+	parameters.enableWritings = config.readEntry( "enable-Writings", true );
 
 	// effects
 	config.setGroup( "Effects" );
-	parameters.enableSphereLight = config.readBoolEntry( "enable-SphericalLight", true );
-	if ( parameters.enableFlash = config.readBoolEntry( "enable-Flash", false ) )
+	parameters.enableSphereLight = config.readEntry( "enable-SphericalLight", true );
+	if ( parameters.enableFlash = config.readEntry( "enable-Flash", false ) )
 	{
-		parameters.flashOpacity = config.readNumEntry( "FlashOpacity", 5 );
+		parameters.flashOpacity = config.readEntry( "FlashOpacity", 5 );
 		if ( parameters.flashOpacity < 0 )
 			parameters.flashOpacity = 0;
 		if ( parameters.flashOpacity > 10 )
 			parameters.flashOpacity = 10;
 	}
-	if ( parameters.enableFade = config.readBoolEntry( "enable-Fade", false ) )
+	if ( parameters.enableFade = config.readEntry( "enable-Fade", false ) )
 	{
-		parameters.fadeAmount = config.readNumEntry( "FadeIntensity", 3 );
+		parameters.fadeAmount = config.readEntry( "FadeIntensity", 3 );
 		if ( parameters.fadeAmount < 0 )
 			parameters.fadeAmount = 0;
 		if ( parameters.fadeAmount > 9 )
 			parameters.fadeAmount = 9;
 	}
-	if ( parameters.enableMegaFlares = config.readBoolEntry( "enable-Flares", true ) )
+	if ( parameters.enableMegaFlares = config.readEntry( "enable-Flares", true ) )
 	{
-		parameters.megaFlares = config.readNumEntry( "FlaresDimension", 5 );
+		parameters.megaFlares = config.readEntry( "FlaresDimension", 5 );
 		if ( parameters.megaFlares < 0 )
 			parameters.megaFlares = 0;
 		if ( parameters.megaFlares > 10 )
@@ -1147,5 +1153,5 @@ void KFireSaver :: readConfig ()
 		parameters.megaFlares += 4;
 		parameters.megaFlares *= 2;
 	}
-	parameters.enableTrails = config.readBoolEntry( "enable-Trail", false );
+	parameters.enableTrails = config.readEntry( "enable-Trail", false );
 }
