@@ -25,13 +25,14 @@
 #include <qdialog.h>
 #include <qtimer.h>
 #include <qstring.h>
-#include <qvaluelist.h>
+#include <q3valuelist.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
-
+//Added by qt3to4:
+#include <QList>
 #include <klocale.h>
 #include <kapplication.h>
 #include <kdebug.h>
@@ -40,48 +41,57 @@
 #include <kfiledialog.h>
 #include <kurl.h>
 #include <kparts/part.h>
-#include <ktrader.h>
 #include <kio/jobclasses.h>
 #include <kio/job.h>
 #include <kmimetype.h>
+#include <kmimetypetrader.h>
 
 #include <kscreensaver.h>
 
-#include "configwidget.h"
 #include "kpartsaver.h"
 #include <kiconloader.h>
+#include <kglobal.h>
 
 
-QPtrList<KPartSaver> g_savers;
+QList<KPartSaver*> g_savers;
 bool g_inited = false;
 
 
-extern "C"
+class KPartSaverInterface : public KScreenSaverInterface
 {
-    KDE_EXPORT const char *kss_applicationName = "kpartsaver";
-    KDE_EXPORT const char *kss_description = I18N_NOOP( "KPart Screen Saver" );
-    KDE_EXPORT const char *kss_version = "1.0";
 
-    KDE_EXPORT KScreenSaver *kss_create( WId d )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "kpartsaver", 0, ki18n( "KPart Screen Saver" ), "1.0", ki18n( "KPart Screen Saver" ) );
+    }
+
+
+    virtual KScreenSaver* create( WId d )
     {
-        KGlobal::locale()->insertCatalogue("kpartsaver");
+        KGlobal::locale()->insertCatalog("kpartsaver");
         return new KPartSaver( d );
     }
 
-    KDE_EXPORT QDialog *kss_setup()
+    virtual QDialog* setup()
     {
-        kdDebug() << "kss_setup" << endl;
-        KGlobal::locale()->insertCatalogue("kpartsaver");
+        KGlobal::locale()->insertCatalog("kpartsaver");
         return new SaverConfig;
     }
+};
+
+int main( int argc, char *argv[] )
+{
+    KPartSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 
 void exitHandler( int )
 {
-    kdDebug() << "exitHandler" << endl;
-    g_savers.clear();
-    KLibLoader::self()->cleanUp();
+    kDebug() << "exitHandler";
+    qDeleteAll(g_savers);
+    //KLibLoader::self()->cleanUp();
     exit(0);
 }
 
@@ -93,7 +103,6 @@ KPartSaver::KPartSaver( WId id )
     // move this into the nspluginviewer kpart code
     if( !g_inited ) {
         g_inited = true;
-        g_savers.setAutoDelete( true );
 
         srand( time(0) );
 
@@ -107,40 +116,37 @@ KPartSaver::KPartSaver( WId id )
 
     g_savers.append( this );
 
-    closeURL();
+    closeUrl();
 
     // load config
-    KConfig *cfg = kapp->config();
-    cfg->setGroup( "Misc" );
+    KConfigGroup cfg(KGlobal::config(), "Misc");
 
-    m_single = cfg->readBoolEntry( "Single", true );
-    m_delay = cfg->readNumEntry( "Delay", 60 );
-    m_random = cfg->readBoolEntry( "Random", false );
-    m_files = cfg->readListEntry( "Files" );
+    m_single = cfg.readEntry( "Single", true );
+    m_delay = cfg.readEntry( "Delay", 60 );
+    m_random = cfg.readEntry( "Random", false );
+    m_files = cfg.readEntry( "Files",QStringList() );
 
     if( m_files.count()==0 ) {
 
         // create background widget
         m_back = new QLabel( i18n("The screen saver is not configured yet."), this );
 
-        m_back->setAlignment( AlignCenter );
+        m_back->setAlignment( Qt::AlignCenter );
         embed( m_back );
         m_back->show();
 
     } else {
 
         // queue files
-        for( unsigned int n=0; n<m_files.count(); n++ )
-            queue( KURL::fromPathOrURL( m_files[n] ) );
+        for( int n=0; n<m_files.count(); n++ )
+            queue( KUrl( m_files[n] ) );
 
         // play files
         if( m_single )
             next( m_random );
         else {
             next( m_random );
-            m_timer = new QTimer( this );
-            m_timer->start( m_delay*1000, true );
-            connect( m_timer, SIGNAL(timeout()), SLOT(timeout()) );
+            QTimer::singleShot( m_delay*1000, this, SLOT(timeout()) );
         }
     }
 }
@@ -148,48 +154,36 @@ KPartSaver::KPartSaver( WId id )
 
 KPartSaver::~KPartSaver()
 {
-    g_savers.take( g_savers.findRef( this ));
-    closeURL();
+    g_savers.removeAll( this );
+    closeUrl();
 }
 
 
-void KPartSaver::closeURL()
+void KPartSaver::closeUrl()
 {
     if( m_part ) {
-        m_part->closeURL();
+        m_part->closeUrl();
         delete m_part;
         m_part = 0;
     }
 }
 
 
-bool KPartSaver::openURL( KURL url )
+bool KPartSaver::openUrl( const KUrl &url )
 {
-    closeURL();
+    if( m_part )
+        closeUrl();
 
     // find mime type
-    QString mime = KMimeType::findByURL( url )->name();
+    QString mime = KMimeType::findByUrl( url )->name();
 
-    // find fitting kparts
-    KTrader::OfferList offers;
-    offers = KTrader::self()->query( mime, "'KParts/ReadOnlyPart' in ServiceTypes" );
-    if( offers.count()==0 ) {
-        kdDebug() << "Can't find proper kpart for " << mime << endl;
-        return false;
-    }
+    // load part
+    m_part = KMimeTypeTrader::createPartInstanceFromQuery<KParts::ReadOnlyPart>(
+        mime, this, this, QString() );
 
-    // load kpart library
-    QString lib = offers.first()->library();
-    KLibFactory *factory = KLibLoader::self()->factory( lib.latin1() );
-    if( !factory ) {
-        kdDebug() << "Library " << lib << " not found." << endl;
-        return false;
-    }
-
-    // create kpart
-    m_part = (KParts::ReadOnlyPart *)factory->create( this, "kpart", "KParts::ReadOnlyPart" );
     if( !m_part ) {
-        kdDebug() << "Part for " << url.url() << " can't be constructed" << endl;
+        kDebug() << "Part for " << url << " can't be constructed";
+        closeUrl();
         return false;
     } else
         embed( m_part->widget() );
@@ -202,19 +196,19 @@ bool KPartSaver::openURL( KURL url )
     m_part->widget()->show();
 
     // load url
-    if( !m_part->openURL( url ) ) {
-        kdDebug() << "Can't load " << url.url() << endl;
-        closeURL();
+    if( !m_part->openUrl( url ) ) {
+        kDebug() << "Can't load " << url.url();
+        delete m_part;
+        m_part = 0;
+        closeUrl();
         return false;
     }
 
-
-
     return true;
 }
 
 
-void KPartSaver::queue( KURL url )
+void KPartSaver::queue( const KUrl &url )
 {
     Medium medium;
     medium.url = url;
@@ -226,7 +220,7 @@ void KPartSaver::queue( KURL url )
 void KPartSaver::timeout()
 {
     next( m_random );
-    m_timer->start( m_delay*1000, true );
+    QTimer::singleShot( m_delay*1000, this, SLOT(timeout()) );
 }
 
 
@@ -243,11 +237,11 @@ void KPartSaver::next( bool random )
         if( m_current>=(int)m_media.count() )
             m_current = 0;
 
-        kdDebug() << "Trying medium " << m_media[m_current].url.url() << endl;
+        kDebug() << "Trying medium " << m_media[m_current].url.url();
 
         // either start immediately or start mimejob first
-        if( !openURL( m_media[m_current].url ) ) {
-            m_media.remove( m_media.at(m_current) );
+        if( !openUrl( m_media[m_current].url ) ) {
+            m_media.removeAll( m_media.at(m_current) );
             m_current--;
         } else
             return;
@@ -257,7 +251,7 @@ void KPartSaver::next( bool random )
     // create background widget
     m_back = new QLabel( i18n("All of your files are unsupported"), this );
 
-    m_back->setAlignment( AlignCenter );
+    m_back->setAlignment( Qt::AlignCenter );
     embed( m_back );
     m_back->show();
 
@@ -269,9 +263,10 @@ void KPartSaver::next( bool random )
 /*******************************************************************************/
 
 
-SaverConfig::SaverConfig( QWidget* parent, const char* name )
-    : ConfigWidget( parent, name, true )
+SaverConfig::SaverConfig( QWidget* parent )
+    : ConfigWidget( parent )
 {
+    setModal(true);
     connect( m_ok, SIGNAL(clicked()), SLOT(apply()) );
     connect( m_ok, SIGNAL(clicked()), SLOT(accept()) );
     connect( m_cancel, SIGNAL(clicked()), SLOT(reject()) );
@@ -281,27 +276,26 @@ SaverConfig::SaverConfig( QWidget* parent, const char* name )
     connect( m_multiple, SIGNAL(toggled(bool)), m_secondsLabel, SLOT(setEnabled(bool)) );
     connect( m_multiple, SIGNAL(toggled(bool)), m_random, SLOT(setEnabled(bool)) );
 
-    connect( m_files, SIGNAL(selectionChanged()), SLOT(select()) );
+    connect( m_files, SIGNAL(itemSelectionChanged()), SLOT(select()) );
     connect( m_add, SIGNAL(clicked()), SLOT(add()) );
     connect( m_remove, SIGNAL(clicked()), SLOT(remove()) );
     connect( m_up, SIGNAL(clicked()), SLOT(up()) );
     connect( m_down, SIGNAL(clicked()), SLOT(down()) );
 
-    m_up->setIconSet( SmallIconSet("up") );
-    m_down->setIconSet( SmallIconSet("down") );
+    m_up->setIcon( KIcon("go-up") );
+    m_down->setIcon( KIcon("go-down") );
 
     // load config
-    KConfig *cfg = kapp->config();
-    cfg->setGroup( "Misc" );
+    KConfigGroup cfg(KGlobal::config(), "Misc");
 
-    bool single = cfg->readBoolEntry( "Single", true );
+    bool single = cfg.readEntry( "Single", true );
     m_single->setChecked( single );
     m_multiple->setChecked( !single );
-    m_delay->setMinValue( 1 );
-    m_delay->setMaxValue( 10000 );
-    m_delay->setValue( cfg->readNumEntry( "Delay", 60 ) );
-    m_random->setChecked( cfg->readBoolEntry( "Random", false ) );
-    m_files->insertStringList( cfg->readListEntry( "Files" ) );
+    m_delay->setMinimum( 1 );
+    m_delay->setMaximum( 10000 );
+    m_delay->setValue( cfg.readEntry( "Delay", 60 ) );
+    m_random->setChecked( cfg.readEntry( "Random", false ) );
+    m_files->addItems( cfg.readEntry( "Files",QStringList() ) );
 
     // update buttons
     select();
@@ -315,72 +309,71 @@ SaverConfig::~SaverConfig()
 
 void SaverConfig::apply()
 {
-    kdDebug() << "apply" << endl;
+    kDebug() << "apply";
 
-    KConfig *cfg = kapp->config();
-    cfg->setGroup( "Misc" );
+    KConfigGroup cfg(KGlobal::config(), "Misc");
 
-    cfg->writeEntry( "Single", m_single->isChecked() );
-    cfg->writeEntry( "Delay", m_delay->value() );
-    cfg->writeEntry( "Random", m_random->isChecked() );
+    cfg.writeEntry( "Single", m_single->isChecked() );
+    cfg.writeEntry( "Delay", m_delay->value() );
+    cfg.writeEntry( "Random", m_random->isChecked() );
 
     int num = m_files->count();
     QStringList files;
     for( int n=0; n<num; n++ )
-        files << m_files->text(n);
+        files << m_files->item(n)->text();
 
-    cfg->writeEntry( "Files", files );
+    cfg.writeEntry( "Files", files );
 
-    cfg->sync();
+    cfg.sync();
 }
 
 
 void SaverConfig::add()
 {
-    KURL::List files = KFileDialog::getOpenURLs( QString::null, QString::null,
+    KUrl::List files = KFileDialog::getOpenUrls( KUrl(), QString(),
                                                  this, i18n("Select Media Files") );
-    for( unsigned int n=0; n<files.count(); n++ )
-        m_files->insertItem( files[n].prettyURL(), -1 );
+    for( int n=0; n<files.count(); n++ )
+        m_files->addItem( files[n].prettyUrl() );
 }
 
 
 void SaverConfig::remove()
 {
-    int current = m_files->currentItem();
+    int current = m_files->currentRow();
     if( current!=-1 )
-        m_files->removeItem( current );
+        m_files->takeItem( current );
 }
 
 
 void SaverConfig::select()
 {
-    bool enabled = m_files->currentItem()!=-1;
+    bool enabled = m_files->currentRow()!=-1;
     m_remove->setEnabled( enabled );
-    m_up->setEnabled( enabled && m_files->currentItem()!=0 );
-    m_down->setEnabled( enabled && m_files->currentItem()!=(int)m_files->count()-1 );
+    m_up->setEnabled( enabled && m_files->currentRow()!=0 );
+    m_down->setEnabled( enabled && m_files->currentRow()!=(int)m_files->count()-1 );
 }
 
 
 void SaverConfig::up()
 {
-    int current = m_files->currentItem();
+    int current = m_files->currentRow();
     if ( current>0 ) {
-        QString txt = m_files->currentText();
-        m_files->removeItem( current );
-        m_files->insertItem( txt, current-1 );
-        m_files->setCurrentItem( current-1 );
+        QString txt = m_files->currentItem()->text();
+        m_files->takeItem( current );
+        m_files->insertItem( current-1, txt );
+        m_files->setCurrentRow( current-1 );
     }
 }
 
 
 void SaverConfig::down()
 {
-    int current = m_files->currentItem();
+    int current = m_files->currentRow();
     if ( current!=-1 && current<(int)m_files->count()-1 ) {
-        QString txt = m_files->currentText();
-        m_files->removeItem( current );
-        m_files->insertItem( txt, current+1 );
-        m_files->setCurrentItem( current+1 );
+        QString txt = m_files->currentItem()->text();
+        m_files->takeItem( current );
+        m_files->insertItem( current+1, txt );
+        m_files->setCurrentRow( current+1 );
     }
 }
 
