@@ -41,27 +41,23 @@
 #include <kvbox.h>
 #include <qlabel.h>
 #include <qfileinfo.h>
-//Added by qt3to4:
 #include <QVBoxLayout>
 #include <QHBoxLayout>
-#include <Q3PtrList>
 #include <QBoxLayout>
 
 #include <kdebug.h>
 #include <kapplication.h>
 #include <kconfig.h>
-#include <k3process.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
+#include <kshell.h>
 #include <kmessagebox.h>
 
 #include "kxsconfig.h"
 #include "kxscontrol.h"
 #include "kxsxml.h"
 
-template class Q3PtrList<KXSConfigItem>;
-
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <X11/IntrinsicP.h>
@@ -80,12 +76,14 @@ const uint widgetEventMask =                 // X event mask
 
 KXSConfigDialog::KXSConfigDialog(const QString &filename, const QString &name)
   : KDialog(0),
-    mFilename(filename), mPreviewProc(0), mKilled(true)
+    mFilename(filename), mPreviewProc(0), mKilled(false)
 {
+    Q_UNUSED(name)
+
     setButtons(Ok| Cancel);
     setDefaultButton( Ok);
     setModal(false);
-    int slash = filename.findRev('/');
+    int slash = filename.lastIndexOf('/');
     if (slash >= 0)
 	mConfigFile = filename.mid(slash+1);
     else
@@ -101,8 +99,11 @@ bool KXSConfigDialog::create()
 {
     QWidget *main = new QWidget(this);
     setMainWidget(main);
-    QVBoxLayout *topLayout = new QVBoxLayout(main, spacingHint());
-    QHBoxLayout *layout = new QHBoxLayout(topLayout, spacingHint());
+    QVBoxLayout *topLayout = new QVBoxLayout(main);
+    topLayout->setSpacing(spacingHint());
+    QHBoxLayout *layout = new QHBoxLayout();
+    topLayout->addLayout(layout);
+    layout->setSpacing(spacingHint());
     KVBox *controlLayout = new KVBox(main);
     controlLayout->setSpacing(spacingHint());
     layout->addWidget(controlLayout);
@@ -120,7 +121,7 @@ bool KXSConfigDialog::create()
 	// We can use the xscreensaver xml config files.
 	KXSXml xmlParser(controlLayout);
 	xmlParser.parse( xmlFile );
-	mConfigItemList = *xmlParser.items();
+	mConfigItemList = xmlParser.items();
 	QWidget *spacer = new QWidget(controlLayout);
 	controlLayout->setStretchFactor(spacer, 1 );
 	QString descr = xmlParser.description();
@@ -163,46 +164,47 @@ bool KXSConfigDialog::create()
 	    return false;
     }
 
-    Q3PtrListIterator<KXSConfigItem> it( mConfigItemList );
-    KXSConfigItem *item;
-    while ( (item = it.current()) != 0 ) {
-	++it;
-	item->read( config );
-        QWidget *i = dynamic_cast<QWidget*>(item);
-        if (i) {
-            connect( i, SIGNAL(changed()), SLOT(slotChanged()) );
+    for ( int i = 0; i < mConfigItemList.size(); i++ ) {
+        KXSConfigItem *item = mConfigItemList[i];
+        item->read( config );
+        QWidget *widget = dynamic_cast<QWidget*>( item );
+        if ( widget ) {
+            connect( widget, SIGNAL(changed()), SLOT(slotChanged()) );
         }
     }
 
-    mPreviewProc = new K3Process;
-    connect(mPreviewProc, SIGNAL(processExited(K3Process *)),
-	    SLOT(slotPreviewExited(K3Process *)));
+    mPreviewProc = new KProcess;
+    connect(mPreviewProc, SIGNAL(finished(int,QProcess::ExitStatus)),
+	    SLOT(slotPreviewProcFinished(int,QProcess::ExitStatus)));
 
     mPreviewTimer = new QTimer(this);
+    mPreviewTimer->setSingleShot(true);
     connect(mPreviewTimer, SIGNAL(timeout()), SLOT(slotNewPreview()));
 
     mPreview = new QWidget(main);
     mPreview->setFixedSize(250, 200);
-    //  mPreview->setBackgroundMode(QWidget::NoBackground);
-    mPreview->setBackgroundColor(Qt::black);
+    {
+        QPalette palette;
+        palette.setColor(mPreview->backgroundRole(), Qt::black);
+        mPreview->setPalette(palette);
+    }
 
-    layout->add(mPreview);
+    layout->addWidget(mPreview);
     show();
 
     // So that hacks can XSelectInput ButtonPressMask
     XSelectInput(QX11Info::display(), mPreview->winId(), widgetEventMask );
 
-    slotPreviewExited(0);
+    startProcess();
     return true;
 }
 
 //---------------------------------------------------------------------------
 KXSConfigDialog::~KXSConfigDialog()
 {
-  if (mPreviewProc && mPreviewProc->isRunning()) {
-    int pid = mPreviewProc->pid();
+  if (mPreviewProc && mPreviewProc->state() == QProcess::Running) {
     mPreviewProc->kill();
-    waitpid(pid, (int *)0, 0);
+    mPreviewProc->waitForFinished(5000);
     delete mPreviewProc;
   }
 }
@@ -211,62 +213,62 @@ KXSConfigDialog::~KXSConfigDialog()
 QString KXSConfigDialog::command()
 {
   QString cmd;
-  KXSConfigItem *item;
 
-  for (item = mConfigItemList.first(); item != 0; item = mConfigItemList.next())
+  for (int i = 0; i < mConfigItemList.size(); i++)
   {
-    cmd += " " + item->command();
+    if (mConfigItemList[i]) {
+      cmd += " " + mConfigItemList[i]->command();
+    }
   }
 
   return cmd;
 }
 
 //---------------------------------------------------------------------------
-void KXSConfigDialog::slotPreviewExited(K3Process *)
+void KXSConfigDialog::startProcess()
 {
+    mKilled = false;
+    mPreviewProc->clearProgram();
+    QString saver = QString( "%1 -window-id 0x%2" )
+        .arg( mFilename )
+        .arg( long(mPreview->winId()), 0, 16 );
+    saver += command();
+    saver = saver.trimmed();
+
+    kDebug() << "Command: " <<  saver;
+
+    int i = 0;
+    QString exe;
+    while ( !saver[i].isSpace() ) {
+        exe += saver[i++];
+    }
+    // work around a KStandarDirs::findExe() "feature" where it looks in
+    // $KDEDIR/bin first no matter what and sometimes finds the wrong executable
+    QFileInfo checkExe;
+    QString saverdir = QString(XSCREENSAVER_HACKS_DIR "/") + exe;
+    QString path;
+    checkExe.setFile(saverdir);
+    if (checkExe.exists() && checkExe.isExecutable() && checkExe.isFile())
+    {
+        path = saverdir;
+    }
+    if (!path.isEmpty()) {
+        (*mPreviewProc) << path;
+
+        (*mPreviewProc) << KShell::splitArgs(saver.mid(i));
+
+        mPreviewProc->start();
+    }
+}
+
+//---------------------------------------------------------------------------
+void KXSConfigDialog::slotPreviewProcFinished(int exitCode, QProcess::ExitStatus exitStatus)
+{
+    Q_UNUSED(exitCode)
+    Q_UNUSED(exitStatus)
+
     if ( mKilled ) {
-	mKilled = false;
-	mPreviewProc->clearArguments();
-	QString saver;
-	saver.sprintf( "%s -window-id 0x%lX", mFilename.latin1(), long(mPreview->winId()) );
-	saver += command();
-	kDebug() << "Command: " <<  saver;
-
-	unsigned int i = 0;
-	QString word;
-	saver = saver.stripWhiteSpace();
-	while ( !saver[i].isSpace() ) word += saver[i++];
-	//work around a KStandarDirs::findExe() "feature" where it looks in $KDEDIR/bin first no matter what and sometimes finds the wrong executable
-	QFileInfo checkExe;
-	QString saverdir = QString("%1/%2").arg(XSCREENSAVER_HACKS_DIR).arg(word);
-	QString path;
-	checkExe.setFile(saverdir);
-	if (checkExe.exists() && checkExe.isExecutable() && checkExe.isFile())
-	{
-		path = saverdir;
-	}
-	if (!path.isEmpty()) {
-	    (*mPreviewProc) << path;
-
-	    bool inQuotes = false;
-	    while ( i < saver.length() ) {
-		word = "";
-		while ( saver[i].isSpace() && i < saver.length() ) i++;
-		while ( (!saver[i].isSpace() || inQuotes) && i < saver.length() ) {
-		    if ( saver[i] == '\"' ) {
-			inQuotes = !inQuotes;
-		    } else {
-			word += saver[i];
-		    }
-		    i++;
-		}
-		if (!word.isEmpty()) {
-		    (*mPreviewProc) << word;
-		}
-	    }
-
-	    mPreviewProc->start();
-	}
+        startProcess();
     } else {
 	// stops us from spawning the hack really fast, but still not the best
 	QString path = KStandardDirs::findExe(mFilename, XSCREENSAVER_HACKS_DIR);
@@ -280,32 +282,30 @@ void KXSConfigDialog::slotPreviewExited(K3Process *)
 //---------------------------------------------------------------------------
 void KXSConfigDialog::slotNewPreview()
 {
-  if (mPreviewProc->isRunning()) {
+  if (mPreviewProc->state() == QProcess::Running) {
     mKilled = true;
     mPreviewProc->kill(); // restarted in slotPreviewExited()
   } else {
-    slotPreviewExited(0);
+    startProcess();
   }
 }
 
 //---------------------------------------------------------------------------
 void KXSConfigDialog::slotChanged()
 {
-    if (mPreviewTimer->isActive())
-	mPreviewTimer->changeInterval(1000);
-    else
-	mPreviewTimer->start(1000, true);
+    mPreviewTimer->start(1000);
 }
 
 //---------------------------------------------------------------------------
 void KXSConfigDialog::slotOk()
 {
-  KXSConfigItem *item;
   KConfig config(mConfigFile);
 
-  for (item = mConfigItemList.first(); item != 0; item = mConfigItemList.next())
+  for (int i = 0; i < mConfigItemList.size(); i++)
   {
-    item->save(config);
+    if (mConfigItemList[i]) {
+      mConfigItemList[i]->save(config);
+    }
   }
 
   kapp->quit();
@@ -383,7 +383,6 @@ int main(int argc, char *argv[])
   KXSConfigDialog *dialog=new KXSConfigDialog(args->arg(0), name);
   if ( dialog->create() ) {
       dialog->show();
-      app.setMainWidget(dialog);
       app.exec();
   } else {
       KMessageBox::sorry(0,
