@@ -24,7 +24,6 @@
 #include <stdio.h>
 #include <unistd.h>
 
-#include <q3ptrlist.h>
 #include <qfile.h>
 #include <qfileinfo.h>
 
@@ -40,8 +39,6 @@
 
 #define MAX_ARGS  30
 
-template class Q3PtrList<KXSConfigItem>;
-
 //===========================================================================
 static const char appName[] = "kxsrun";
 
@@ -74,7 +71,7 @@ int main(int argc, char *argv[])
     QString configFile(filename);
 
     // Get the config filename
-    int slash = filename.findRev('/');
+    int slash = filename.lastIndexOf('/');
     if (slash >= 0)
 	configFile = filename.mid(slash+1);
 
@@ -84,7 +81,7 @@ int main(int argc, char *argv[])
     // read configuration args
     KConfig config(configFile);
 
-    Q3PtrList<KXSConfigItem> configItemList;
+    QList<KXSConfigItem*> configItemList;
 
     QString xmlFile = "/doesntexist";
 #ifdef XSCREENSAVER_CONFIG_DIR
@@ -95,12 +92,9 @@ int main(int argc, char *argv[])
 	// We can use the xscreensaver xml config files.
 	KXSXml xmlParser(0);
 	xmlParser.parse(xmlFile);
-	configItemList = *xmlParser.items();
-	Q3PtrListIterator<KXSConfigItem> it( configItemList );
-	KXSConfigItem *item;
-	while ( (item = it.current()) != 0 ) {
-	    ++it;
-	    item->read( config );
+	configItemList = xmlParser.items();
+        for ( int i = 0; i < configItemList.size(); i++ ) {
+	    configItemList[i]->read( config );
 	}
     } else {
 	// fall back to KDE's old config files.
@@ -136,29 +130,32 @@ int main(int argc, char *argv[])
     QFileInfo checkExe;
     QString saverdir = QString("%1/%2").arg(XSCREENSAVER_HACKS_DIR).arg(filename);
     kDebug() << "saverdir is" << saverdir;
-    QString exeFile;
+    QByteArray exeFile;
     checkExe.setFile(saverdir);
     if (checkExe.exists() && checkExe.isExecutable() && checkExe.isFile())
     {
-        exeFile = saverdir;
+        exeFile = QFile::encodeName(saverdir);
     }
 
 
     if (!exeFile.isEmpty()) {
 	char *sargs[MAX_ARGS];
-	sargs[0] = new char [strlen(filename.ascii())+1];
-	strcpy(sargs[0], filename.ascii());
+
+        {
+            QByteArray encodedFile = QFile::encodeName(filename);
+            sargs[0] = new char [encodedFile.size()+1];
+            strcpy(sargs[0], encodedFile.constData());
+        }
 
 	// add the command line options
 	QString cmd;
-	unsigned int i;
-	for (i = 1; i < (unsigned)args->count(); i++)
+	int i;
+	for (i = 1; i < args->count(); i++)
 	    cmd += " " + QString(args->arg(i));
 
 	// add the config options
-	KXSConfigItem *item;
-	for (item = configItemList.first(); item != 0; item = configItemList.next()) {
-	    cmd += " " + item->command();
+        for ( int i = 0; i < configItemList.size(); i++ ) {
+	    cmd += " " + configItemList[i]->command();
 	}
 
 	// put into char * array for execv
@@ -178,8 +175,10 @@ int main(int argc, char *argv[])
 		i++;
 	    }
 	    if (!word.isEmpty()) {
-		sargs[si] = new char [strlen(word.ascii())+1];
-		strcpy(sargs[si], word.ascii());
+                // filenames are likely to be the troublesome encodings
+                QByteArray encodedWord = QFile::encodeName(word);
+		sargs[si] = new char [encodedWord.size()+1];
+		strcpy(sargs[si], encodedWord.constData());
 		si++;
 	    }
 	}
@@ -187,7 +186,7 @@ int main(int argc, char *argv[])
 	sargs[si] = 0;
 
 	// here goes...
-	execv(exeFile.ascii(), sargs);
+	execv(exeFile.constData(), sargs);
     }
 }
 
